yacm: yet another config module
===============================

.. image:: https://img.shields.io/pypi/v/yacm.svg
        :target: https://pypi.python.org/pypi/yacm


* Free software: Apache Software License 2.0
